@@ -5,8 +5,7 @@
 #' @references Rice, A., L. Glick, S. Abadi, M. Einhorn, N.M. Kopelman, A. Salman-Minkov, J. Mayzel, O. Chay, and I. Mayrose. 2014. The Chromosome Counts Database (CCDB) -- a community resource of plant chromosome numbers. New Phytologist doi:10.1111/nph.13191.
 #'
 #' @docType package
-#' @name chromer
-#' @aliases chromer-chromer chromer
+#' @keywords internal
 #' @importFrom stats na.omit
 #'
-NULL
+"_PACKAGE"
